<?php

namespace Litecms\GoogleCaptcha\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\GoogleCaptcha\Http\Requests\CaptchaSettingRequest;
use Litecms\GoogleCaptcha\Interfaces\CaptchaSettingRepositoryInterface;
use Litecms\GoogleCaptcha\Models\CaptchaSetting;

/**
 * Resource controller class for captcha_setting.
 */
class CaptchaSettingResourceController extends BaseController
{

    /**
     * Initialize captcha_setting resource controller.
     *
     * @param type CaptchaSettingRepositoryInterface $captcha_setting
     *
     * @return null
     */
    public function __construct(CaptchaSettingRepositoryInterface $captcha_setting)
    {
        parent::__construct();
        $this->repository = $captcha_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\GoogleCaptcha\Repositories\Criteria\CaptchaSettingResourceCriteria::class);
    }

    /**
     * Display a list of captcha_setting.
     *
     * @return Response
     */
    public function index(CaptchaSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\GoogleCaptcha\Repositories\Presenter\CaptchaSettingPresenter::class)
                ->$function();
        }

        $captcha_settings = $this->repository->paginate();

        return $this->response->title(trans('google_captcha::captcha_setting.names'))
            ->view('google_captcha::captcha_setting.index', true)
            ->data(compact('captcha_settings'))
            ->output();
    }

    /**
     * Display captcha_setting.
     *
     * @param Request $request
     * @param Model   $captcha_setting
     *
     * @return Response
     */
    public function show(CaptchaSettingRequest $request, CaptchaSetting $captcha_setting)
    {

        if ($captcha_setting->exists) {
            $view = 'google_captcha::captcha_setting.show';
        } else {
            $view = 'google_captcha::captcha_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('google_captcha::captcha_setting.name'))
            ->data(compact('captcha_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new captcha_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CaptchaSettingRequest $request)
    {

        $captcha_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('google_captcha::captcha_setting.name')) 
            ->view('google_captcha::captcha_setting.create', true) 
            ->data(compact('captcha_setting'))
            ->output();
    }

    /**
     * Create new captcha_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CaptchaSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $captcha_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('google_captcha::captcha_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('google_captcha/captcha_setting/' . $captcha_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/google_captcha/captcha_setting'))
                ->redirect();
        }

    }

    /**
     * Show captcha_setting for editing.
     *
     * @param Request $request
     * @param Model   $captcha_setting
     *
     * @return Response
     */
    public function edit(CaptchaSettingRequest $request, CaptchaSetting $captcha_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('google_captcha::captcha_setting.name'))
            ->view('google_captcha::captcha_setting.edit', true)
            ->data(compact('captcha_setting'))
            ->output();
    }

    /**
     * Update the captcha_setting.
     *
     * @param Request $request
     * @param Model   $captcha_setting
     *
     * @return Response
     */
    public function update(CaptchaSettingRequest $request, CaptchaSetting $captcha_setting)
    {
        try {
            $attributes = $request->all();

            $captcha_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('google_captcha::captcha_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('google_captcha/captcha_setting/' . $captcha_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('google_captcha/captcha_setting/' . $captcha_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the captcha_setting.
     *
     * @param Model   $captcha_setting
     *
     * @return Response
     */
    public function destroy(CaptchaSettingRequest $request, CaptchaSetting $captcha_setting)
    {
        try {

            $captcha_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('google_captcha::captcha_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('google_captcha/captcha_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('google_captcha/captcha_setting/' . $captcha_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple captcha_setting.
     *
     * @param Model   $captcha_setting
     *
     * @return Response
     */
    public function delete(CaptchaSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('google_captcha::captcha_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('google_captcha/captcha_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/google_captcha/captcha_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted captcha_settings.
     *
     * @param Model   $captcha_setting
     *
     * @return Response
     */
    public function restore(CaptchaSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('google_captcha::captcha_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/google_captcha/captcha_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/google_captcha/captcha_setting/'))
                ->redirect();
        }

    }

}
